# -*- encoding: utf-8 -*-

import hashlib

from django.conf import settings
from django.contrib.auth.backends import ModelBackend
from django.contrib.auth.models import User

from auf.django.references.models import Authentification as RemoteUser


class RefAuthBackend(ModelBackend):
    """
    Authentification selon la table ref_authentification uniquement.
    (Il n'y a plus de fallback sur les users locaux comme dans les versions
    précédentes)
    """

    def authenticate(self, username=None, password=None):
        if username.endswith("@auf.org"):
            username = username.replace("@auf.org", "")

        email = "%s@auf.org" % username
        md5pass = hashlib.md5(password.encode('utf-8')).hexdigest()
        
        try:
            if getattr(settings, 'AUTH_PASSWORD_REQUIRED', True):
                remoteUser = RemoteUser.objects.get(courriel=email,
                        motdepasse=md5pass)
            else:
                remoteUser = RemoteUser.objects.get(courriel=email)
        except:
            return None

        prenom_nom = email.replace('@auf.org', '')
        prenom, sep, nom = prenom_nom.partition('.')
        remoteUser.prenom = prenom.title()
        remoteUser.nom = nom.title()

        user, created = User.objects.get_or_create(email=email)
        if created:
            user.username = username
            user.email = email
            user.first_name = remoteUser.prenom
            user.last_name = remoteUser.nom
            user.is_staff = getattr(settings, 'CREATE_USER_WITH_STAFF', False)
            user.is_active = True
            user.is_superuser = False
            user.save()

        return user
